@@ -13,7 +13,7 @@ Usage::
 """
 import sys
 from datetime import datetime
-from typing import Any, Dict, List, Union
+from typing import Any, Dict, List, Mapping, Sequence, Union
 
 from .literals import (
     ActionCategoryType,
@@ -274,9 +274,9 @@ _OptionalActionDeclarationTypeDef = TypedDict(
     "_OptionalActionDeclarationTypeDef",
     {
         "runOrder": int,
-        "configuration": Dict[str, str],
-        "outputArtifacts": List["OutputArtifactTypeDef"],
-        "inputArtifacts": List["InputArtifactTypeDef"],
+        "configuration": Mapping[str, str],
+        "outputArtifacts": Sequence["OutputArtifactTypeDef"],
+        "inputArtifacts": Sequence["InputArtifactTypeDef"],
         "roleArn": str,
         "region": str,
         "namespace": str,
@@ -641,8 +641,8 @@ _OptionalCreateCustomActionTypeInputRequestTypeDef = TypedDict(
     "_OptionalCreateCustomActionTypeInputRequestTypeDef",
     {
         "settings": "ActionTypeSettingsTypeDef",
-        "configurationProperties": List["ActionConfigurationPropertyTypeDef"],
-        "tags": List["TagTypeDef"],
+        "configurationProperties": Sequence["ActionConfigurationPropertyTypeDef"],
+        "tags": Sequence["TagTypeDef"],
     },
     total=False,
 )
@@ -673,7 +673,7 @@ _RequiredCreatePipelineInputRequestTypeDef = TypedDict(
 _OptionalCreatePipelineInputRequestTypeDef = TypedDict(
     "_OptionalCreatePipelineInputRequestTypeDef",
     {
-        "tags": List["TagTypeDef"],
+        "tags": Sequence["TagTypeDef"],
     },
     total=False,
 )
@@ -1212,14 +1212,14 @@ _RequiredPipelineDeclarationTypeDef = TypedDict(
     {
         "name": str,
         "roleArn": str,
-        "stages": List["StageDeclarationTypeDef"],
+        "stages": Sequence["StageDeclarationTypeDef"],
     },
 )
 _OptionalPipelineDeclarationTypeDef = TypedDict(
     "_OptionalPipelineDeclarationTypeDef",
     {
         "artifactStore": "ArtifactStoreTypeDef",
-        "artifactStores": Dict[str, "ArtifactStoreTypeDef"],
+        "artifactStores": Mapping[str, "ArtifactStoreTypeDef"],
         "version": int,
     },
     total=False,
@@ -1290,7 +1290,7 @@ _OptionalPollForJobsInputRequestTypeDef = TypedDict(
     "_OptionalPollForJobsInputRequestTypeDef",
     {
         "maxBatchSize": int,
-        "queryParam": Dict[str, str],
+        "queryParam": Mapping[str, str],
     },
     total=False,
 )
@@ -1398,7 +1398,7 @@ _OptionalPutJobSuccessResultInputRequestTypeDef = TypedDict(
         "currentRevision": "CurrentRevisionTypeDef",
         "continuationToken": str,
         "executionDetails": "ExecutionDetailsTypeDef",
-        "outputVariables": Dict[str, str],
+        "outputVariables": Mapping[str, str],
     },
     total=False,
 )
@@ -1453,7 +1453,7 @@ _RequiredPutWebhookInputRequestTypeDef = TypedDict(
 _OptionalPutWebhookInputRequestTypeDef = TypedDict(
     "_OptionalPutWebhookInputRequestTypeDef",
     {
-        "tags": List["TagTypeDef"],
+        "tags": Sequence["TagTypeDef"],
     },
     total=False,
 )
@@ -1560,13 +1560,13 @@ _RequiredStageDeclarationTypeDef = TypedDict(
     "_RequiredStageDeclarationTypeDef",
     {
         "name": str,
-        "actions": List["ActionDeclarationTypeDef"],
+        "actions": Sequence["ActionDeclarationTypeDef"],
     },
 )
 _OptionalStageDeclarationTypeDef = TypedDict(
     "_OptionalStageDeclarationTypeDef",
     {
-        "blockers": List["BlockerDeclarationTypeDef"],
+        "blockers": Sequence["BlockerDeclarationTypeDef"],
     },
     total=False,
 )
@@ -1670,7 +1670,7 @@ TagResourceInputRequestTypeDef = TypedDict(
     "TagResourceInputRequestTypeDef",
     {
         "resourceArn": str,
-        "tags": List["TagTypeDef"],
+        "tags": Sequence["TagTypeDef"],
     },
 )
 
@@ -1731,7 +1731,7 @@ UntagResourceInputRequestTypeDef = TypedDict(
     "UntagResourceInputRequestTypeDef",
     {
         "resourceArn": str,
-        "tagKeys": List[str],
+        "tagKeys": Sequence[str],
     },
 )
 
